==> xmame_0.29.2.orig.tar.gz: xmame-0.29.2/src/unix/solaris_i386.c <==
/*
* Solaris dependent code
*
* Preliminary audio support by jantonio@dit.upm.es
* no control on mono/stereo output channel and so  (yet)
*
*/

#ifdef solaris

#define __SOLARIS_C
#include "xmame.h"
#include "sound.h"
#include "lin2ulaw.h"

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/stropts.h>
#include <sys/audioio.h>

int audioctl_fd; 		/* audio control device for solaris */
int written = 0;		/* number of bytes written */

audio_info_t    	a_info; /* info about audio settings */
audio_device_t		a_dev;  /* info about audio hardware */

int sysdep_init(void) {

	int	i;
	if (play_sound) {
		int supported=FALSE;
                printf ("Solaris sound device initialization...\n");
                /* try to open audio device */
                if ( (audio_fd=open("/dev/audio",O_WRONLY | O_NDELAY)) < 0)
                {
                        printf ("couldn't open audio device\n");
                        exit(1);
                }
                /* try to open audioctl device */
                if ( (audioctl_fd=open("/dev/audioctl",O_RDWR | O_NDELAY)) < 0)
                {
                        printf ("couldn't open audioctl device\n");
			close(audio_fd);
                        exit(1);
                }
	       	
		/* empty buffers before change config */
        	ioctl(audio_fd, AUDIO_DRAIN, 0);    /* drain everything out */
        	ioctl(audio_fd, I_FLUSH, FLUSHRW);  /* flush everything     */
        	ioctl(audioctl_fd, I_FLUSH, FLUSHRW);   /* flush everything */            

		/* identify audio device. if AMD chipset, bad, luck :-( */
		if(ioctl(audio_fd,AUDIO_GETDEV,&a_dev)<0) {
			printf("Cannot get sound device type\n");
			close(audio_fd);
			close(audioctl_fd);
			exit(1);
		}
		printf("Sound device is a %s %s version %s\n",a_dev.config,a_dev.name,a_dev.version);
		
                /* get audio parameters. */ 
                ioctl(audioctl_fd,AUDIO_GETINFO,&a_info);
                AUDIO_INITINFO(&a_info);

		if (strcmp(a_dev.name,"SUNW,sbpro")==0) {
			supported=TRUE;
			audio_sample_freq	  = AUDIO_SAMPLE_FREQ;
                	a_info.play.sample_rate   = (uint_t) audio_sample_freq;
                	a_info.record.sample_rate = (uint_t) audio_sample_freq;
                	a_info.play.encoding      = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.record.encoding    = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.play.precision     = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.record.precision   = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.play.channels      = (uint_t) 1;   	/* mono */
                	a_info.record.channels    = (uint_t) 1;
		}
		if (strcmp(a_dev.name,"SUNW,sb16")==0) {
			supported=TRUE;
			audio_sample_freq	  = AUDIO_SAMPLE_FREQ;
                	a_info.play.sample_rate   = (uint_t) audio_sample_freq;
                	a_info.record.sample_rate = (uint_t) audio_sample_freq;
                	a_info.play.encoding      = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.record.encoding    = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.play.precision     = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.record.precision   = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.play.channels      = (uint_t) 1;   	/* mono */
                	a_info.record.channels    = (uint_t) 1;
		}
		if (supported==FALSE) {
			printf("Unsupported audio chipset %s \n",a_dev.name);
			printf("Please contact with authors\n");
			close(audioctl_fd);
			close(audio_fd);
			exit(1);
		}

                a_info.play.port          = (uint_t) AUDIO_SPEAKER;
                a_info.play.gain          = (uint_t) 130; 	/* volume */
		a_info.monitor_gain       = 0;  		/* no bypass */
		a_info.output_muted	  = 0; 			/* not muted */
		a_info.record.buffer_size = 1024;
		a_info.play.buffer_size = 1024;
		i=0;
                if ( ioctl(audio_fd,AUDIO_SETINFO,&a_info) < 0 )	i+=2;
		if (i) { 
                        printf ("Error %d: cannot set audio device parameters\n",i);
                        close(audio_fd);
                        close(audioctl_fd);
                        exit(1);
                }
        }
        return (TRUE);
}

void sysdep_exit(void) {
	if (play_sound) {
		close(audio_fd);
		close(audioctl_fd);
	}
}	

int sysdep_play_audio(byte *buf, int bufsize)
{
    int i;
    /* 8 bits signed linear 22050hz */
    			
    i = write(audio_fd,buf,bufsize);
    written += i;
    return(i);
}

long sysdep_get_audio_freespace()
{
	ioctl(audioctl_fd,AUDIO_GETINFO,&a_info);
	return(AUDIO_BUFF_SIZE - written + a_info.play.samples);
}

#endif

==> xmame_0.34b5.2.orig.tar.gz: xmame-0.34b5.2/src/unix/solaris_i386.c <==
/*
* Solaris dependent code
*
* Preliminary audio support by jantonio@dit.upm.es
* no control on mono/stereo output channel and so  (yet)
*
*/

#ifdef solaris

#define __SOLARIS_C
#include "xmame.h"
#include "sound.h"
#include "lin2ulaw.h"

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/stropts.h>
#include <sys/audioio.h>

int audioctl_fd; 		/* audio control device for solaris */
int written = 0;		/* number of bytes written */

audio_info_t    	a_info; /* info about audio settings */
audio_device_t		a_dev;  /* info about audio hardware */

int sysdep_init(void) {

	int	i;
	if (play_sound) {
		int supported=FALSE;
                fprintf(stderr_file, "Solaris sound device initialization...\n");
                /* try to open audio device */
                if ( (audio_fd=open("/dev/audio",O_WRONLY | O_NDELAY)) < 0)
                {
                        fprintf(stderr_file, "couldn't open audio device\n");
                        exit(1);
                }
                /* try to open audioctl device */
                if ( (audioctl_fd=open("/dev/audioctl",O_RDWR | O_NDELAY)) < 0)
                {
                        fprintf(stderr_file, "couldn't open audioctl device\n");
			close(audio_fd);
                        exit(1);
                }
	       	
		/* empty buffers before change config */
        	ioctl(audio_fd, AUDIO_DRAIN, 0);    /* drain everything out */
        	ioctl(audio_fd, I_FLUSH, FLUSHRW);  /* flush everything     */
        	ioctl(audioctl_fd, I_FLUSH, FLUSHRW);   /* flush everything */            

		/* identify audio device. if AMD chipset, bad, luck :-( */
		if(ioctl(audio_fd,AUDIO_GETDEV,&a_dev)<0) {
			fprintf(stderr_file, "Cannot get sound device type\n");
			close(audio_fd);
			close(audioctl_fd);
			exit(1);
		}
		fprintf(stderr_file, "Sound device is a %s %s version %s\n",a_dev.config,a_dev.name,a_dev.version);
		
                /* get audio parameters. */ 
                ioctl(audioctl_fd,AUDIO_GETINFO,&a_info);
                AUDIO_INITINFO(&a_info);

		if (strcmp(a_dev.name,"SUNW,sbpro")==0) {
			supported=TRUE;
			options.samplerate	  = AUDIO_SAMPLE_FREQ;
                	a_info.play.sample_rate   = (uint_t) options.samplerate;
                	a_info.record.sample_rate = (uint_t) options.samplerate;
                	a_info.play.encoding      = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.record.encoding    = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.play.precision     = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.record.precision   = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.play.channels      = (uint_t) 1;   	/* mono */
                	a_info.record.channels    = (uint_t) 1;
		}
		if (strcmp(a_dev.name,"SUNW,sb16")==0) {
			supported=TRUE;
			options.samplerate	  = AUDIO_SAMPLE_FREQ;
                	a_info.play.sample_rate   = (uint_t) options.samplerate;
                	a_info.record.sample_rate = (uint_t) options.samplerate;
                	a_info.play.encoding      = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.record.encoding    = (uint_t) AUDIO_ENCODING_LINEAR;
                	a_info.play.precision     = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.record.precision   = (uint_t) AUDIO_SAMPLE_BITS;
                	a_info.play.channels      = (uint_t) 1;   	/* mono */
                	a_info.record.channels    = (uint_t) 1;
		}
		if (supported==FALSE) {
			fprintf(stderr_file, "Unsupported audio chipset %s \n",a_dev.name);
			fprintf(stderr_file, "Please contact with authors\n");
			close(audioctl_fd);
			close(audio_fd);
			exit(1);
		}

                a_info.play.port          = (uint_t) AUDIO_SPEAKER;
                a_info.play.gain          = (uint_t) 130; 	/* volume */
		a_info.monitor_gain       = 0;  		/* no bypass */
		a_info.output_muted	  = 0; 			/* not muted */
		a_info.record.buffer_size = 1024;
		a_info.play.buffer_size = 1024;
		i=0;
                if ( ioctl(audio_fd,AUDIO_SETINFO,&a_info) < 0 )	i+=2;
		if (i) { 
                        fprintf(stderr_file, "Error %d: cannot set audio device parameters\n",i);
                        close(audio_fd);
                        close(audioctl_fd);
                        exit(1);
                }
        }
        return (TRUE);
}

void sysdep_exit(void) {
	if (play_sound) {
		close(audio_fd);
		close(audioctl_fd);
	}
}	

int sysdep_play_audio(byte *buf, int bufsize)
{
    int i;
    /* 8 bits signed linear 22050hz */
    			
    i = write(audio_fd,buf,bufsize);
    written += i;
    return(i);
}

long sysdep_get_audio_freespace()
{
	ioctl(audioctl_fd,AUDIO_GETINFO,&a_info);
	return(AUDIO_BUFF_SIZE - written + a_info.play.samples);
}

#endif
